const FIELD_CONTENT_REGEXP = /^[\u0009\u0020-\u007e\u0080-\u00ff]+$/;
const validateName = (name) => {
    if (name && !FIELD_CONTENT_REGEXP.test(name)) {
        throw new TypeError(`Invalid cookie name: "${name}".`);
    }
};
const toString = (cookie) => {
    validateName(cookie.name);
    let out = [`${cookie.name}=${cookie.value}`];
    if (cookie.name.startsWith('__Secure')) {
        cookie.secure = true;
    }
    if (cookie.name.startsWith('__Host')) {
        cookie.path = '/';
        cookie.secure = true;
        delete cookie.domain;
    }
    if (cookie.secure) {
        out.push('Secure');
    }
    if (cookie.httpOnly) {
        out.push('HttpOnly');
    }
    if (typeof cookie.maxAge === 'number' && Number.isInteger(cookie.maxAge)) {
        if (cookie.maxAge < 0)
            throw new Error('Max-Age must be an integer superior or equal to 0');
        out.push(`Max-Age=${cookie.maxAge}`);
    }
    if (cookie.domain) {
        // validateDomain(cookie.domain)
        out.push(`Domain=${cookie.domain}`);
    }
    if (cookie.sameSite) {
        out.push(`SameSite=${cookie.sameSite}`);
    }
    if (cookie.path) {
        // validatePath(cookie.path)
        out.push(`Path=${cookie.path}`);
    }
    if (cookie.expires) {
        out.push(`Expires=${(typeof cookie.expires == 'number' ? new Date(cookie.expires) : cookie.expires).toUTCString()}`);
    }
    return out.join('; ');
};
export const getCookies = (headers) => {
    const cookie = headers.get('Cookie');
    if (cookie != null) {
        const out = {};
        const c = cookie.split(';');
        for (const kv of c) {
            const [cookieKey, ...cookieVal] = kv.split('=');
            const key = cookieKey.trim();
            out[key] = cookieVal.join('=');
        }
        return out;
    }
    return {};
    // const cookiePairs = headers.get('cookie')!
    //   .split('; ')
    //   .map(pair => pair.split('=', 2)) as [string, string][]
};
export const setCookie = (headers, cookie) => {
    headers.append('set-cookie', toString(cookie));
};
export class Cookies {
    #header;
    constructor(header) {
        this.#header = header;
    }
    set(cookie) {
        setCookie(this.#header, cookie);
    }
    delete(cookie) {
        this.set({
            ...cookie,
            value: '',
            expires: new Date(0),
        });
    }
}
