import { ErrorStatus } from './httpStatus.js';
declare const ERROR_STATUS_MAP: {
    readonly BadRequest: 400;
    readonly Unauthorized: 401;
    readonly PaymentRequired: 402;
    readonly Forbidden: 403;
    readonly NotFound: 404;
    readonly MethodNotAllowed: 405;
    readonly NotAcceptable: 406;
    readonly ProxyAuthRequired: 407;
    readonly RequestTimeout: 408;
    readonly Conflict: 409;
    readonly Gone: 410;
    readonly LengthRequired: 411;
    readonly PreconditionFailed: 412;
    readonly RequestEntityTooLarge: 413;
    readonly RequestURITooLong: 414;
    readonly UnsupportedMediaType: 415;
    readonly RequestedRangeNotSatisfiable: 416;
    readonly ExpectationFailed: 417;
    readonly Teapot: 418;
    readonly MisdirectedRequest: 421;
    readonly UnprocessableEntity: 422;
    readonly Locked: 423;
    readonly FailedDependency: 424;
    readonly UpgradeRequired: 426;
    readonly PreconditionRequired: 428;
    readonly TooManyRequests: 429;
    readonly RequestHeaderFieldsTooLarge: 431;
    readonly UnavailableForLegalReasons: 451;
    readonly InternalServerError: 500;
    readonly NotImplemented: 501;
    readonly BadGateway: 502;
    readonly ServiceUnavailable: 503;
    readonly GatewayTimeout: 504;
    readonly HTTPVersionNotSupported: 505;
    readonly VariantAlsoNegotiates: 506;
    readonly InsufficientStorage: 507;
    readonly LoopDetected: 508;
    readonly NotExtended: 510;
    readonly NetworkAuthenticationRequired: 511;
};
export type ErrorStatusKeys = keyof typeof ERROR_STATUS_MAP;
export type HttpErrorInit = ErrorStatusKeys | string;
export interface HttpErrorOptions extends ErrorOptions {
    expose?: boolean;
    headers?: HeadersInit;
    status?: number;
    description?: string;
}
export declare class HttpError extends Error {
    #private;
    constructor(message?: HttpErrorInit, options?: HttpErrorOptions);
    /** A flag to indicate if the internals of the error, like the stack, should
     * be exposed to a client, or if they are "private" and should not be leaked.
     * By default, all client errors are `true` and all server errors are
     * `false`. */
    get expose(): boolean;
    /** The optional headers object that is set on the error. */
    get headers(): Headers | undefined;
    /** The error status that is set on the error. */
    get status(): ErrorStatus;
    get description(): string;
}
/** A type guard that determines if the value is an HttpError or not. */
export declare function isHttpError(value: unknown): value is HttpError;
export {};
