/// <reference types="node" resolution-mode="require"/>
/// <reference types="node" resolution-mode="require"/>
/// <reference types="node" resolution-mode="require"/>
/// <reference types="node" resolution-mode="require"/>
import http from 'http';
import http2 from 'http2';
import https from 'https';
import type net from 'net';
type ListenOptionsHttp = net.ListenOptions & {
    transport?: 'http';
    server?: http.ServerOptions;
};
type ListenOptionsHttps = net.ListenOptions & {
    transport: 'https';
    server: https.ServerOptions;
};
type ListenOptionsH2c = net.ListenOptions & {
    transport: 'h2c';
    server?: http2.ServerOptions;
};
type ListenOptionsH2 = net.ListenOptions & {
    transport: 'h2';
    server: http2.SecureServerOptions;
};
export type ServerListenOptions = ListenOptionsHttp | ListenOptionsHttps | ListenOptionsH2c | ListenOptionsH2;
type ServerType<T = ServerListenOptions> = T extends ListenOptionsHttp ? http.Server : T extends ListenOptionsHttps ? https.Server : T extends ListenOptionsH2 ? http2.Http2SecureServer : T extends ListenOptionsH2c ? http2.Http2Server : never;
type ServerHandle = (request: Request) => Response | Promise<Response>;
export declare class Server {
    /**
     * @example
     * const app = new App()
     * Server.listen(app.fetch, {transport: 'http', port: 50000})
     * // or
     * Server.listen(request => new Response('321'), {transport: 'http', port: 50000})
     * */
    static listen<T extends ServerListenOptions>(handle: ServerHandle, options: T, listener?: () => void): ServerType<T>;
}
export {};
