import http from 'http';
import http2 from 'http2';
import https from 'https';
import { h2respondWith, h2streamToWeb, requestToWeb, respondWith } from './lib/node-web.js';
export class Server {
    /**
     * @example
     * const app = new App()
     * Server.listen(app.fetch, {transport: 'http', port: 50000})
     * // or
     * Server.listen(request => new Response('321'), {transport: 'http', port: 50000})
     * */
    static listen(handle, options, listener) {
        // default http server
        if (!options.transport)
            options.transport = 'http';
        if (options.transport === 'http') {
            const server = http.createServer(options.server);
            server.listen(options, listener);
            server.on('request', async (req, res) => {
                const request = requestToWeb(req);
                respondWith(res, await handle(request)).catch(reason => {
                    console.error(reason);
                });
            });
            return server;
        }
        if (options.transport === 'https') {
            const server = https.createServer(options.server);
            server.listen(options, listener);
            server.on('request', async (req, res) => {
                const request = requestToWeb(req);
                respondWith(res, await handle(request)).catch(reason => {
                    console.error(reason);
                });
            });
            return server;
        }
        if (options.transport === 'h2c') {
            const server = http2.createServer(options.server);
            server.listen(options, listener);
            server.on('stream', async (stream, headers) => {
                const request = h2streamToWeb(stream, headers);
                h2respondWith(stream, await handle(request)).catch(reason => {
                    console.error(reason);
                });
            });
            return server;
        }
        if (options.transport === 'h2') {
            const server = http2.createSecureServer(options.server);
            server.listen(options, listener);
            server.on('stream', async (stream, headers) => {
                const request = h2streamToWeb(stream, headers);
                h2respondWith(stream, await handle(request)).catch(reason => {
                    console.error(reason);
                });
            });
            return server;
        }
    }
}
